@@ -5,7 +5,7 @@ use Encode qw(decode);
 use base 'Exporter';
 our @EXPORT = qw(convert_to_ascii);
 our @EXPORT_OK = qw(convert_to_ascii);
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 my %char_map;
 
 =encoding utf8
@@ -3883,32 +3883,32 @@ FFEE 6F
 1F12C 28+52+29
 1F12D 28+43+44+29
 1F12E 28+57+5A+29
-1F130 5B+41+5D
-1F131 5B+42+5D
-1F132 5B+43+5D
-1F133 5B+44+5D
-1F134 5B+45+5D
-1F135 5B+46+5D
-1F136 5B+47+5D
-1F137 5B+48+5D
-1F138 5B+49+5D
-1F139 5B+4A+5D
-1F13A 5B+4B+5D
-1F13B 5B+4C+5D
-1F13C 5B+4D+5D
-1F13D 5B+4E+5D
-1F13E 5B+4F+5D
-1F13F 5B+50+5D
-1F140 5B+51+5D
-1F141 5B+52+5D
-1F142 5B+53+5D
-1F143 5B+54+5D
-1F144 5B+55+5D
-1F145 5B+56+5D
-1F146 5B+57+5D
-1F147 5B+58+5D
-1F148 5B+59+5D
-1F149 5B+5A+5D
+1F130 41
+1F131 42
+1F132 43
+1F133 44
+1F134 45
+1F135 46
+1F136 47
+1F137 48
+1F138 49
+1F139 4A
+1F13A 4B
+1F13B 4C
+1F13C 4D
+1F13D 4E
+1F13E 4F
+1F13F 50
+1F140 51
+1F141 52
+1F142 53
+1F143 54
+1F144 55
+1F145 56
+1F146 57
+1F147 58
+1F148 59
+1F149 5A
 1F14A 5B+48+56+5D
 1F14B 5B+4D+56+5D
 1F14C 5B+53+44+5D
@@ -3945,32 +3945,32 @@ FFEE 6F
 1F16B 4D+44
 1F16C 4D+52
 1F16D 28+43+43+29
-1F170 5B+41+5D
-1F171 5B+42+5D
-1F172 5B+43+5D
-1F173 5B+44+5D
-1F174 5B+45+5D
-1F175 5B+46+5D
-1F176 5B+47+5D
-1F177 5B+48+5D
-1F178 5B+49+5D
-1F179 5B+4A+5D
-1F17A 5B+4B+5D
-1F17B 5B+4C+5D
-1F17C 5B+4D+5D
-1F17D 5B+4E+5D
-1F17E 5B+4F+5D
-1F17F 5B+50+5D
-1F180 5B+51+5D
-1F181 5B+52+5D
-1F182 5B+53+5D
-1F183 5B+54+5D
-1F184 5B+55+5D
-1F185 5B+56+5D
-1F186 5B+57+5D
-1F187 5B+58+5D
-1F188 5B+59+5D
-1F189 5B+5A+5D
+1F170 41
+1F171 42
+1F172 43
+1F173 44
+1F174 45
+1F175 46
+1F176 47
+1F177 48
+1F178 49
+1F179 4A
+1F17A 4B
+1F17B 4C
+1F17C 4D
+1F17D 4E
+1F17E 4F
+1F17F 50
+1F180 51
+1F181 52
+1F182 53
+1F183 54
+1F184 55
+1F185 56
+1F186 57
+1F187 58
+1F188 59
+1F189 5A
 1F18A 5B+50+5D
 1F18B 5B+49+43+5D
 1F18C 5B+50+41+5D
@@ -3997,7 +3997,7 @@ FFEE 6F
 1F1A2 5B+32+32+2E+31+5D
 1F1A3 5B+36+30+70+5D
 1F1A4 5B+31+32+30+70+5D
-1F1A5 5B+64+5D
+1F1A5 64
 1F1A6 5B+48+43+5D
 1F1A7 5B+48+44+52+5D
 1F1AA 5B+53+48+56+5D
